# workaround debug-id conflicts (with clisp)
# https://bugs.mageia.org/show_bug.cgi?id=22545
# https://bugzilla.redhat.com/show_bug.cgi?id=1458416
%global _build_id_links none
# debuginfo.list ends up empty/blank anyway. disable
%global debug_package   %{nil}
# Inhibit automatic compressing of info files.
# Compressed info files break maxima's internal help.
%global __spec_install_post %{nil}

%define enable_pdfdoc    1

%define enable_tests     1

%define enable_gcl       1
%define enable_ecl       1
%define enable_clisp     1
%define enable_sbcl      1
%define enable_sbcl_exec 1
%define defaultlisp      sbcl

%ifarch aarch64
  %define enable_gcl     0
%endif

%if %enable_clisp
  %define clisp_flags	--enable-clisp
%else
  %define clisp_flags	--disable-clisp
%endif

%if %enable_gcl
  %define gcl_flags	--enable-gcl
%else
  %define gcl_flags	--disable-gcl
%endif

%if %enable_sbcl
  %if %enable_sbcl_exec
    %define sbcl_flags	--enable-sbcl-exec
  %else
    %define sbcl_flags  --enable-sbcl
  %endif
%else
  %define sbcl_flags	--disable-sbcl
%endif

%if %enable_ecl
  %define ecl_flags	--enable-ecl
%else
  %define ecl_flags	--disable-ecl
%endif

Name:           maxima
Version:        5.47.0
Release:        %mkrel 3
Summary:        Symbolic Computation Program
License:        GPLv2
Group:          Sciences/Mathematics
URL:            https://maxima.sourceforge.net/
Source0:        https://downloads.sourceforge.net/maxima/%{name}-%{version}.tar.gz
Source1:        icons-maxima.tar.bz2
Patch0:         maxima-5.45.1-xdg-utils.patch
Patch1:         maxima-fix-contrib-docs.patch
Patch2:         maxima-5.47.0-pdf-manual-a4-paper-size.patch

# From FC
## upstreamable patches
# https://bugzilla.redhat.com/show_bug.cgi?id=837142
# https://sourceforge.net/tracker/?func=detail&aid=3539587&group_id=4933&atid=104933
Patch50:	maxima-5.37.1-clisp-noreadline.patch

# handle multiple ldflags in ecl build
Patch52:	maxima-ecl_ldflags.patch

# Invoke python3 instead of python
Patch53:	maxima-5.47.0-python3.patch

# From Arch
Patch100:	matrixexp.patch
Source101:	maxima-sbcl-gmp.patch

BuildRequires:  desktop-file-utils
BuildRequires:  emacs
BuildRequires:  git
BuildRequires:  python3
BuildRequires:  recode
BuildRequires:  texinfo
BuildRequires:  texinfo-tex
BuildRequires:  texlive
BuildRequires:  time
BuildRequires:  tk

%if %{enable_clisp}
BuildRequires:  clisp
%endif

%if %{enable_gcl}
BuildRequires:  gcl
%else
Obsoletes:      %{name}-runtime-gcl < %{version}-%{release}
%endif

%if %{enable_sbcl}
BuildRequires:  sbcl
%define sbcl_version %(sbcl --version 2>/dev/null | cut -d' ' -f2)
%endif

%if %{enable_ecl}
BuildRequires:  ecl
BuildRequires:	pkgconfig(atomic_ops)
%else
Obsoletes:	%{name}-runtime-ecl < %{version}-%{release}
%endif

Requires:       %{name}-runtime-%{defaultlisp} = %{version}-%{release}
Requires:       gnuplot
Requires:	rlwrap

Recommends:     tk
Recommends:     tcl


%description
Maxima is a full symbolic computation program.  It is full featured doing
symbolic manipulation of polynomials, matrices, rational functions,
integration, Todd-coxeter, graphing, bigfloats.  It has a symbolic debugger
source level debugger for maxima code.  Maxima is based on the original Macsyma
developed at MIT in the 1970's. It is quite reliable, and has good garbage
collection, and no memory leaks. It comes with hundreds of self tests.


#--------------------------------------------------------------------

%package gui
Summary:        Tcl/Tk GUI interface to Maxima
Group:          Sciences/Mathematics
Requires:       %{name}
Requires:       tk
Provides:       x%{name} = %{version}-%{release}

%description gui
Tcl/Tk GUI interface to Maxima.


%files gui
%{_bindir}/x%{name}
%{_datadir}/applications/mageia-%{name}.desktop
%{_iconsdir}/hicolor/*/apps/*.png

#--------------------------------------------------------------------

%if %{enable_clisp}
%package runtime-clisp
Summary:        Maxima compiled with clisp
Group:          Sciences/Mathematics
Requires:       clisp
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-runtime = %{version}-%{release}

%description runtime-clisp
Maxima compiled with clisp.


%files runtime-clisp
%dir %{_libdir}/%{name}/%{version}/binary-clisp
%{_libdir}/%{name}/%{version}/binary-clisp/*
%endif

#--------------------------------------------------------------------

%if %{enable_gcl}
%package runtime-gcl
Summary:        Maxima compiled with GCL
Group:          Sciences/Mathematics
Requires:       %{name} = %{version}-%{release}
Recommends:     rlwrap
Provides:       %{name}-runtime = %{version}-%{release}

%description runtime-gcl
Maxima compiled with Gnu Common Lisp.


%files runtime-gcl
%{_bindir}/r%{name}
%dir %{_libdir}/%{name}/%{version}/binary-gcl
%{_libdir}/%{name}/%{version}/binary-gcl/*
%endif

#--------------------------------------------------------------------
%if %{enable_sbcl}
%package runtime-sbcl
Summary:        Maxima compiled with SBCL
Group:          Sciences/Mathematics
%if ! %enable_sbcl_exec
Requires:       sbcl = %{sbcl_version}
%endif
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-runtime = %{version}-%{release}

%description runtime-sbcl
Maxima compiled with SBCL.


%files runtime-sbcl
%dir %{_libdir}/%{name}/%{version}/binary-sbcl
%{_libdir}/%{name}/%{version}/binary-sbcl/*
%endif

%if %{enable_ecl}
%package runtime-ecl
Summary:        Maxima compiled with ECL
Group:          Sciences/Mathematics
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-runtime = %{version}-%{release}

%description runtime-ecl
Maxima compiled with ECL.


%files runtime-ecl
%dir %{_libdir}/%{name}/%{version}/binary-ecl
%{_libdir}/%{name}/%{version}/binary-ecl/*
%endif

#--------------------------------------------------------------------

%prep
%autosetup -p1

%build
export PYTHON=%{__python3}

# suppress warnings
autoreconf -vfi

%configure \
	%{clisp_flags} \
	--disable-cmucl \
	%{ecl_flags} \
	%{gcl_flags} \
	%{sbcl_flags} \
	--with-default-lisp=%{defaultlisp}

%make_build

%if %{enable_pdfdoc}
make -C doc/info pdf
%endif

%if %{enable_tests}
%check
make -k check ||:
%endif

%install
export EXCLUDE_FROM_COMPRESS='maxima-index\.lisp|maxima\.info'
%make_install

# menu
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}.desktop << EOF
[Desktop Entry]
Name=Maxima
Comment=Tcl/Tk interface to Maxima
Exec=%{_bindir}/x%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Science;Math;
EOF

# icons
mkdir -p %{buildroot}%{_iconsdir}
tar xjf %{SOURCE1} -C %{buildroot}%{_iconsdir}

# remove /usr/share/info/dir generated file
rm -f %{buildroot}%{_datadir}/info/dir

%find_lang %{name} --with-man

%files -f %{name}.lang
%doc AUTHORS COPYING README
%if %{enable_clisp}
%doc README-lisps.md
%endif
%if %{enable_pdfdoc}
%doc doc/info/%{name}.pdf
%endif
%{_bindir}/%{name}
%{_bindir}/r%{name}
%{_bindir}/x%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/net.sourceforge.maxima.x%{name}.desktop
%{_metainfodir}/net.sourceforge.maxima.x%{name}.appdata.xml
%{_datadir}/bash-completion/completions/*maxima
%{_datadir}/mime/packages/x-ma*.xml
%{_datadir}/emacs/site-lisp/*
%{_datadir}/pixmaps/*%{name}*.png
%{_datadir}/pixmaps/*%{name}*.svg
%{_infodir}/*.info*
%{_infodir}/%{name}-index*.lisp*
%{_libexecdir}/%{name}/
%{_mandir}/man1/%{name}.1*


%changelog
* Mon Jun 09 2025 daviddavid <daviddavid> 5.47.0-3.mga10
+ Revision: 2190127
- rebuild with fixed ecl-24.5.10-3.mga10

* Sun Nov 10 2024 daviddavid <daviddavid> 5.47.0-2.mga10
+ Revision: 2113418
- rebuild for new ecl 24.5.10

* Sun Nov 05 2023 daviddavid <daviddavid> 5.47.0-1.mga10
+ Revision: 2004489
- new version: 5.47.0

* Thu Jan 12 2023 daviddavid <daviddavid> 5.46.0-4.mga9
+ Revision: 1932559
- rebuild for new libunistring 1.1

* Mon Nov 21 2022 ghibo <ghibo> 5.46.0-3.mga9
+ Revision: 1909693
- Rebuild against newer sbcl

* Mon Oct 31 2022 ghibo <ghibo> 5.46.0-2.mga9
+ Revision: 1900713
- Rebuild fore core/release

* Sun Oct 30 2022 ghibo <ghibo> 5.46.0-1.mga9
+ Revision: 1900577
- Update to release 5.46.0.
- Remove fasl patch (Patch52).
- Rework Patch53 (python3).

* Sun Oct 30 2022 ghibo <ghibo> 5.45.1-1.mga9
+ Revision: 1900495
- Add missed BR for ecl
- Add missed BRs
- Update to release 5.45.1.
- Rework Patch0 for 5.45.1.
- Sync patchset with FC.
- Merge Patch100 from Arch.
- Add missed rlwrap to Requires.
- Enable tests and doc building.
- Pass --disable-cmucl to configure options.
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Oct 10 2020 wally <wally> 5.44.0-1.mga8
+ Revision: 1633084
- new version 5.44.0

* Sun May 24 2020 wally <wally> 5.43.2-6.mga8
+ Revision: 1587423
- build with python3

* Sat Feb 22 2020 wally <wally> 5.43.2-5.mga8
+ Revision: 1549232
- fix internal help

* Thu Feb 20 2020 wally <wally> 5.43.2-4.mga8
+ Revision: 1547352
- create maxima executable image when building with sbcl

* Mon Feb 17 2020 wally <wally> 5.43.2-3.mga8
+ Revision: 1537455
- disable gcl build on aarch64 for now
- replace deprecated %%configure2_5x
- drop unneeded post and postun scriptlets
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ daviddavid <daviddavid>
- new version: 5.43.2
+ tv <tv>
- rebuild for new readline
+ akien <akien>
- Version 5.42.2

* Sun Oct 14 2018 wally <wally> 5.42.0-1.mga7
+ Revision: 1320262
- new version 5.42.0
- use sbcl as default lisp implementation
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
+ daviddavid <daviddavid>
- rebuild for new sbcl 1.4.6

* Fri Feb 09 2018 wally <wally> 5.41.0-2.mga7
+ Revision: 1199908
- workaround debug-id conflicts with clisp (mga#22545)

* Sun Jan 21 2018 wally <wally> 5.41.0-1.mga7
+ Revision: 1195544
- new version 5.41.0
- rebuild for new readline

* Mon Jul 03 2017 pterjan <pterjan> 5.40.0-2.mga6
+ Revision: 1109010
- Disable clisp and sbcl on arm, we don't have them there yet

* Sat Jun 03 2017 akien <akien> 5.40.0-1.mga6
+ Revision: 1105963
- Version 5.40.0

* Sat May 27 2017 neoclust <neoclust> 5.39.0-2.mga6
+ Revision: 1105124
- Rebuilf for ARM

* Sun Jan 29 2017 akien <akien> 5.39.0-1.mga6
+ Revision: 1084096
- Version 5.39.0

* Wed May 11 2016 akien <akien> 5.38.0-1.mga6
+ Revision: 1012420
- Disable PDF doc for now, pdftex fails
- Version 5.38.0

* Tue Mar 01 2016 wally <wally> 5.37.3-3.mga6
+ Revision: 981633
- disable tests for now (hangs on i586)
+ akien <akien>
- Version 5.37.3

* Sat Sep 19 2015 wally <wally> 5.37.2-1.mga6
+ Revision: 881296
- new version 5.37.2

* Thu Jul 23 2015 wally <wally> 5.36.1-1.mga6
+ Revision: 856591
- new version 5.36.1

* Sat Jun 20 2015 wally <wally> 5.36.0-1.mga6
+ Revision: 836623
- new version 5.36.0

* Wed Feb 11 2015 wally <wally> 5.35.1-1.mga5
+ Revision: 814669
- new version 5.35.1
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.32.1-3.mga5
+ Revision: 682304
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Wed Jan 22 2014 shlomif <shlomif> 5.32.1-2.mga4
+ Revision: 567471
- Rebuild for new SBCL.

* Sun Jan 05 2014 dmorgan <dmorgan> 5.32.1-1.mga4
+ Revision: 564785
- New version ( builds against new texlive)
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 kamil <kamil> 5.29.1-5.mga4
+ Revision: 436765
- rebuild for new sbcl 1.1.8 and new ecl 13.5.1

* Sun Feb 03 2013 kamil <kamil> 5.29.1-4.mga3
+ Revision: 394229
- rebuild against sbcl 1.1.4

* Mon Jan 14 2013 umeabot <umeabot> 5.29.1-3.mga3
+ Revision: 386058
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 kamil <kamil> 5.29.1-2.mga3
+ Revision: 333427
- rebuild against new ecl

* Sun Dec 16 2012 kamil <kamil> 5.29.1-1.mga3
+ Revision: 331826
- disable P3
- new version 5.29.1

* Thu Dec 13 2012 kamil <kamil> 5.27.0-4.mga3
+ Revision: 330542
- reeaneble ecl build

* Tue Dec 11 2012 kamil <kamil> 5.27.0-3.mga3
+ Revision: 329817
- add texinfo-tex as BR
- rebuild against new sbcl

* Mon May 28 2012 kamil <kamil> 5.27.0-2.mga3
+ Revision: 247737
- new version 5.27.0

* Sat Apr 07 2012 pterjan <pterjan> 5.26.0-2.mga2
+ Revision: 229449
- Obsolete runtime-ecl
- Do not compress info pages, this breaks internal help
- Disable ecl
- Require sbcl version used to build. If a given one is needed it should be a BuildRequires
+ kamil <kamil>
- reenable 'make check'

* Wed Jan 18 2012 kamil <kamil> 5.26.0-0.3.mga2
+ Revision: 197753
- reenable gcl build
- drop missed-extract-categories.patch (merged upstream)

* Wed Jan 18 2012 kamil <kamil> 5.26.0-0.2.mga2
+ Revision: 197747
- reenable ecl build
- remove EXCLUDE_FROM_COMPRESS for info-pages

* Wed Jan 18 2012 kamil <kamil> 5.26.0-0.1.mga2
+ Revision: 197742
- reenable sbcl build

* Wed Jan 11 2012 kamil <kamil> 5.26.0-0.mga2
+ Revision: 194948
- temporarily disable gcl and ecl build
- add tk, desktop-file-utils and time to BR
- disable make check
- new version
- spec cleaning a bit

* Thu May 05 2011 grenoya <grenoya> 5.24.0-1.mga1
+ Revision: 95217
- clean old Mdv syntax
- diseable sbcl
+ tv <tv>
- fix texlive BR
- new release
+ dmorgan <dmorgan>
- Fix desktop file name
- imported package maxima


* Wed Feb 02 2011 Paulo Andrade <pcpa@mandriva.com.br> 5.23.0-1mdv2011.0
+ Revision: 635334
- Require explicit sbcl version
- Remove cmucl backend conditional generation
- Enable all lisp backends
- Add back the clisp-noreadline patch to disable readline when running under sagemath

  + Александр Казанцев <kazancas@mandriva.org>
    - new release 5.23.0

* Fri Dec 17 2010 Александр Казанцев <kazancas@mandriva.org> 5.22.1-3mdv2011.0
+ Revision: 622594
- set clisp default due non-latin enviroment error

* Sun Aug 22 2010 Paulo Andrade <pcpa@mandriva.com.br> 5.22.1-2mdv2011.0
+ Revision: 572046
- Update to version 5.22.1
- Update to version 5.22.0

* Mon Apr 19 2010 Frederik Himpe <fhimpe@mandriva.org> 5.20.1-8mdv2010.1
+ Revision: 536862
- Rebuild for new sbcl

* Wed Mar 03 2010 Frederik Himpe <fhimpe@mandriva.org> 5.20.1-7mdv2010.1
+ Revision: 514006
- Rebuild for new sbcl

* Tue Mar 02 2010 Paulo Andrade <pcpa@mandriva.com.br> 5.20.1-6mdv2010.1
+ Revision: 513704
- Enable ecl as a maxima lisp backend
- Add ecl to list of maxima runtime lisps
- Make runtimes owners of it's directories

* Wed Feb 10 2010 Funda Wang <fwang@mandriva.org> 5.20.1-5mdv2010.1
+ Revision: 503752
- rebuild

* Wed Feb 10 2010 Funda Wang <fwang@mandriva.org> 5.20.1-4mdv2010.1
+ Revision: 503636
- rebuild for new gmp

* Fri Feb 05 2010 Frederik Himpe <fhimpe@mandriva.org> 5.20.1-3mdv2010.1
+ Revision: 501269
- Rebuild for new SBCL

* Fri Jan 01 2010 Frederik Himpe <fhimpe@mandriva.org> 5.20.1-2mdv2010.1
+ Revision: 484902
- Rebuild for new sbcl

* Wed Dec 16 2009 Frederik Himpe <fhimpe@mandriva.org> 5.20.1-1mdv2010.1
+ Revision: 479588
- update to new version 5.20.1

* Wed Nov 25 2009 Frederik Himpe <fhimpe@mandriva.org> 5.19.2-3mdv2010.1
+ Revision: 470125
- Fix summary of sbcl subpackage
- Rebuild for new gcl and binutils (libfd)

* Wed Nov 11 2009 Frederik Himpe <fhimpe@mandriva.org> 5.19.2-2mdv2010.1
+ Revision: 464397
- Rebuild for new sbcl and gcl

* Sun Sep 13 2009 Frederik Himpe <fhimpe@mandriva.org> 5.19.2-1mdv2010.0
+ Revision: 439030
- update to new version 5.19.2

* Sun Aug 30 2009 Frederik Himpe <fhimpe@mandriva.org> 5.19.1-2mdv2010.0
+ Revision: 422449
- Rebuild for new sbcl

* Thu Aug 27 2009 Frederik Himpe <fhimpe@mandriva.org> 5.19.1-1mdv2010.0
+ Revision: 421784
- Update to new version 5.19.1
- Rediff noreadline patch

* Wed Aug 19 2009 Paulo Andrade <pcpa@mandriva.com.br> 5.18.1-3mdv2010.0
+ Revision: 418334
- Pass -I option to clisp if --disable-readline option is used
- Rebuild with newer clisp and gcl

* Wed Jul 29 2009 Frederik Himpe <fhimpe@mandriva.org> 5.18.1-2mdv2010.0
+ Revision: 404436
- Rebuild for new sbcl and clisp

* Thu Jun 04 2009 Frederik Himpe <fhimpe@mandriva.org> 5.18.1-1mdv2010.0
+ Revision: 382883
- Update to new version 5.18.1

* Wed Mar 11 2009 Frederik Himpe <fhimpe@mandriva.org> 5.17.1-4mdv2009.1
+ Revision: 353928
- Rebuild for new sbcl

* Thu Mar 05 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.17.1-3mdv2009.1
+ Revision: 349355
- rebuild again to really link against new readline

* Sat Feb 28 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.17.1-2mdv2009.1
+ Revision: 346035
- rebuild against new readline

* Fri Feb 06 2009 Frederik Himpe <fhimpe@mandriva.org> 5.17.1-1mdv2009.1
+ Revision: 338272
- update to new version 5.17.1

* Thu Feb 05 2009 Frederik Himpe <fhimpe@mandriva.org> 5.17.0-3mdv2009.1
+ Revision: 337978
- Rebuild for new sbcl

* Mon Jan 05 2009 Frederik Himpe <fhimpe@mandriva.org> 5.17.0-2mdv2009.1
+ Revision: 325124
- Rebuild for new sbcl

* Sat Dec 06 2008 Frederik Himpe <fhimpe@mandriva.org> 5.17.0-1mdv2009.1
+ Revision: 310920
- Update to new version 5.17.0

* Fri Oct 31 2008 Frederik Himpe <fhimpe@mandriva.org> 5.16.3-4mdv2009.1
+ Revision: 299064
- Rebuild for new sbcl

* Mon Oct 13 2008 Funda Wang <fwang@mandriva.org> 5.16.3-2mdv2009.1
+ Revision: 293066
- hardcode sbcl version (bug#44840)

* Mon Sep 01 2008 Frederik Himpe <fhimpe@mandriva.org> 5.16.3-2mdv2009.0
+ Revision: 278719
- Build SBCL runtime and set it as default, like upstream recommends
  (http://maxima.sourceforge.net/wiki/index.php/Lisp)
- Build clisp runtime on x86_64 again, it works now
- Don't package ChangeLog (outdated) and INSTALL

* Sat Aug 30 2008 Frederik Himpe <fhimpe@mandriva.org> 5.16.3-1mdv2009.0
+ Revision: 277600
- Update to new version 5.16.3
- Fix license

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

  + Adam Williamson <awilliamson@mandriva.org>
    - reduce tk and tcl to suggests rather than requires (#39518, Michael Koren)

* Sat May 03 2008 Funda Wang <fwang@mandriva.org> 5.15.0-1mdv2009.0
+ Revision: 200604
- drop unused patch
- New version 5.15.0

  + Giuseppe Ghibò <ghibo@mandriva.com>
    - Fix docs for grobner contrib.

* Fri Apr 25 2008 Giuseppe Ghibò <ghibo@mandriva.com> 5.14.0-2mdv2009.0
+ Revision: 197362
- Added tetex-latex, tetex-dvips and python to BuildRequires.
- Added Patch1, Patch2 to fix documentation.
- Fixed docs.

* Sat Apr 19 2008 Giuseppe Ghibò <ghibo@mandriva.com> 5.14.0-1mdv2009.0
+ Revision: 195775
- Release 5.14.0.

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag

* Mon Jan 28 2008 Adam Williamson <awilliamson@mandriva.org> 5.13.0-5mdv2008.1
+ Revision: 158937
- runtime-gcl suggests rlwrap (Fred Himpe, #36035)

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 24 2007 Adam Williamson <awilliamson@mandriva.org> 5.13.0-4mdv2008.0
+ Revision: 92661
- correct binary name in menu entry (launch xmaxima, the graphical front end, not maxima, the console one: bug #33930)

* Fri Sep 21 2007 Adam Williamson <awilliamson@mandriva.org> 5.13.0-3mdv2008.0
+ Revision: 92040
- no longer requires gv due to patch
- add maxima-5.13.0-xdg-utils.patch to use xdg-open instead of specific binaries (from Gentoo, MDV bug #33867)

* Wed Sep 05 2007 Adam Williamson <awilliamson@mandriva.org> 5.13.0-2mdv2008.0
+ Revision: 80500
- reduce menu categories as per frederik

* Tue Sep 04 2007 Adam Williamson <awilliamson@mandriva.org> 5.13.0-1mdv2008.0
+ Revision: 79401
- add more menu categories
- slightly rearrange spec
- regenerate icons-maxima.tar.bz2 to use fd.o icon naming scheme
- use Fedora license policy (GPL+)
- new release 5.13.0

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Sun May 27 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 5.12.0-2mdv2008.0
+ Revision: 31828
- Rebuild against new Maxima

* Tue May 08 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 5.12.0-1mdv2008.0
+ Revision: 25348
- New version


* Fri Jan 05 2007 Nicolas Lécureuil <neoclust@mandriva.org> 5.11.0-2mdv2007.0
+ Revision: 104538
- Rediff Patch0

* Fri Jan 05 2007 Nicolas Lécureuil <neoclust@mandriva.org> 5.11.0-1mdv2007.1
+ Revision: 104408
- New version  5.11.0
- Add Menu entry
- Import maxima

* Wed Apr 12 2006 Giuseppe Ghibò <ghibo@mandriva.com> 5.9.3-1mdk
- Release 5.9.3.

* Mon Nov 07 2005 Giuseppe Ghibò <ghibo@mandriva.com> 5.9.2-1mdk
- Release 5.9.2.
- Rebuilt Patch0.

* Thu Aug 04 2005 Giuseppe Ghibò <ghibo@mandriva.com> 5.9.1-5mdk
- Rebuilt against gcl 2.6.7-0.cvs20050803 and gcc 4.0.1.

* Mon Apr 18 2005 Giuseppe Ghibò <ghibo@mandriva.com> 5.9.1-4mdk
- Don't use clisp for X86-64 for now (clisp failed to build
  under X86-64).

* Thu Feb 17 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 5.9.1-3mdk
- Added gv in Requires.

* Wed Feb 16 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 5.9.1-2mdk
- Added Patch0 (use gv instead of ghostview).

* Wed Feb 16 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 5.9.1-1mdk
- Release: 5.9.1.

* Wed Mar 24 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 5.9.0-6mdk
- Fixed typo in menu entry.

